@@ -1,3 +1,4 @@
+# rev 1.4: fixed crash on zero intersection, thanks to nathan.cornwell@optum.com
 # Rev 1.2: added checks for empty-set inputs
 #Jan2021: clean up & speed up
 
@@ -5,9 +6,11 @@
 vintersect <- function(x, y, multiple=TRUE){
 # base::intersect does as.vector internally
 	 # really can start out with this if() and just return vector() {logical(0)}
- if(!length(x) | !length(y)) return( vector() )
+xtype <- typeof(x)
+ if(!length(x) | !length(y)) return( vector(mode = xtype) )
  # make output look just like base::intersect 
-    
+# is there something in the intersection?
+if (!length(intersect(x,y)))   return( vector(mode = xtype) )
 if(multiple) {
 	x <- as.vector(x)
 	y <- as.vector(y)
